==> jc-1.4.0.tar.gz: javax/imageio/stream/FileImageInputStream.h <==
// public class javax.imageio.stream.FileImageInputStream

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bd756184e426c473 javax_imageio_stream_FileImageInputStream
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl

// header file dependencies
// @dep_header javax_imageio_stream_ImageInputStreamImpl

#include "javax/imageio/stream/ImageInputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_FileImageInputStream_H_
#define _JC_javax_imageio_stream_FileImageInputStream_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_RandomAccessFile$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_FileImageInputStream$sub_refs	_jc_javax_imageio_stream_FileImageInputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_FileImageInputStream$sub_nonrefs	_jc_javax_imageio_stream_FileImageInputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_FileImageInputStream$refs	_jc_javax_imageio_stream_FileImageInputStream$refs;
typedef struct _jc_javax_imageio_stream_FileImageInputStream$nonrefs	_jc_javax_imageio_stream_FileImageInputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_FileImageInputStream$object	_jc_javax_imageio_stream_FileImageInputStream$object;

typedef const struct _jc_javax_imageio_stream_FileImageInputStream$vmethods	_jc_javax_imageio_stream_FileImageInputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_FileImageInputStream$vtable	_jc_javax_imageio_stream_FileImageInputStream$vtable;
typedef const struct _jc_javax_imageio_stream_FileImageInputStream$vtype	_jc_javax_imageio_stream_FileImageInputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_FileImageInputStream$method$_init$538ee07130435a5e(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, struct _jc_java_io_File$object *);
extern void _jc_javax_imageio_stream_FileImageInputStream$method$_init$d89f2e0d09a08bf1(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, struct _jc_java_io_RandomAccessFile$object *);

// Virtual methods
extern void _jc_javax_imageio_stream_FileImageInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *);
extern jlong _jc_javax_imageio_stream_FileImageInputStream$method$length$c5778ac730410d75(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *);
extern jint _jc_javax_imageio_stream_FileImageInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *);
extern jint _jc_javax_imageio_stream_FileImageInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_javax_imageio_stream_FileImageInputStream$method$seek$d605bbca03fdd295(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_FileImageInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_FileImageInputStream$method_info$length$c5778ac730410d75;
extern _jc_method _jc_javax_imageio_stream_FileImageInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_FileImageInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_javax_imageio_stream_FileImageInputStream$method_info$seek$d605bbca03fdd295;

// Virtual methods structure
struct _jc_javax_imageio_stream_FileImageInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *);
	jlong	(*length$c5778ac730410d75)(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*seek$d605bbca03fdd295)(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, jlong);
};

// Vtable
struct _jc_javax_imageio_stream_FileImageInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_FileImageInputStream$vmethods	javax_imageio_stream_FileImageInputStream;
};

// Vtype
struct _jc_javax_imageio_stream_FileImageInputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_FileImageInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileImageInputStream$sub_refs {
	struct _jc_java_io_RandomAccessFile$object	*file;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_FileImageInputStream$refs {
    _jc_javax_imageio_stream_FileImageInputStream$sub_refs	javax_imageio_stream_FileImageInputStream;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileImageInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_FileImageInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_FileImageInputStream$sub_nonrefs	javax_imageio_stream_FileImageInputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_FileImageInputStream$object {
	_jc_javax_imageio_stream_FileImageInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_FileImageInputStream$vtype	*vtype;
	_jc_javax_imageio_stream_FileImageInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_FileImageInputStream$vtype _jc_javax_imageio_stream_FileImageInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_FileImageInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_FileImageInputStream$class_object;

#endif	/* _JC_javax_imageio_stream_FileImageInputStream_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/stream/FileImageInputStream.h <==
// public class javax.imageio.stream.FileImageInputStream

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bd756184e426c473 javax_imageio_stream_FileImageInputStream
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl

// header file dependencies
// @dep_header javax_imageio_stream_ImageInputStreamImpl

#include "javax/imageio/stream/ImageInputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_FileImageInputStream_H_
#define _JC_javax_imageio_stream_FileImageInputStream_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_RandomAccessFile$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_FileImageInputStream$sub_refs	_jc_javax_imageio_stream_FileImageInputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_FileImageInputStream$sub_nonrefs	_jc_javax_imageio_stream_FileImageInputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_FileImageInputStream$refs	_jc_javax_imageio_stream_FileImageInputStream$refs;
typedef struct _jc_javax_imageio_stream_FileImageInputStream$nonrefs	_jc_javax_imageio_stream_FileImageInputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_FileImageInputStream$object	_jc_javax_imageio_stream_FileImageInputStream$object;

typedef const struct _jc_javax_imageio_stream_FileImageInputStream$vmethods	_jc_javax_imageio_stream_FileImageInputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_FileImageInputStream$vtable	_jc_javax_imageio_stream_FileImageInputStream$vtable;
typedef const struct _jc_javax_imageio_stream_FileImageInputStream$vtype	_jc_javax_imageio_stream_FileImageInputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_FileImageInputStream$method$_init$538ee07130435a5e(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_FileImageInputStream$method$_init$d89f2e0d09a08bf1(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, struct _jc_java_io_RandomAccessFile$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_imageio_stream_FileImageInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *) _JC_JCNI_ATTR;
extern jlong _jc_javax_imageio_stream_FileImageInputStream$method$length$c5778ac730410d75(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_FileImageInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_FileImageInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_FileImageInputStream$method$seek$d605bbca03fdd295(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_FileImageInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_FileImageInputStream$method_info$length$c5778ac730410d75;
extern _jc_method _jc_javax_imageio_stream_FileImageInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_FileImageInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_javax_imageio_stream_FileImageInputStream$method_info$seek$d605bbca03fdd295;

// Virtual methods structure
struct _jc_javax_imageio_stream_FileImageInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *) _JC_JCNI_ATTR;
	jlong	(*length$c5778ac730410d75)(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*seek$d605bbca03fdd295)(_jc_env *, struct _jc_javax_imageio_stream_FileImageInputStream$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_stream_FileImageInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_FileImageInputStream$vmethods	javax_imageio_stream_FileImageInputStream;
};

// Vtype
struct _jc_javax_imageio_stream_FileImageInputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_FileImageInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileImageInputStream$sub_refs {
	struct _jc_java_io_RandomAccessFile$object	*file;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_FileImageInputStream$refs {
    _jc_javax_imageio_stream_FileImageInputStream$sub_refs	javax_imageio_stream_FileImageInputStream;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileImageInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_FileImageInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_FileImageInputStream$sub_nonrefs	javax_imageio_stream_FileImageInputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_FileImageInputStream$object {
	_jc_javax_imageio_stream_FileImageInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_FileImageInputStream$vtype	*vtype;
	_jc_javax_imageio_stream_FileImageInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_FileImageInputStream$vtype _jc_javax_imageio_stream_FileImageInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_FileImageInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_FileImageInputStream$class_object;

#endif	/* _JC_javax_imageio_stream_FileImageInputStream_H_ */
